@@ -92,14 +92,30 @@ function helpMe (opts) {
     return out
   }
 
-  function toStdout (args) {
-    createStream(args)
-      .on('error', function () {
-        console.log('no such help file\n')
-        toStdout()
-      })
-      .pipe(process.stdout)
+  function toStdout (args = [], opts) {
+    opts = opts || {}
+    const stream = opts.stream || process.stdout
+    const _onMissingHelp = opts.onMissingHelp || onMissingHelp
+    return new Promise((resolve, reject) => {
+      createStream(args)
+        .on('error', (err) => {
+          _onMissingHelp(err, args, stream).then(resolve, reject)
+        })
+        .pipe(stream)
+        .on('close', resolve)
+        .on('end', resolve)
+    })
+  }
+
+  function onMissingHelp (_, args, stream) {
+    stream.write(`no such help file: ${args.join(' ')}.\n\n`)
+    return toStdout([], { stream, async onMissingHelp () {} })
   }
 }
 
+function help (opts, args) {
+  return helpMe(opts).toStdout(args, opts)
+}
+
 module.exports = helpMe
+module.exports.help = help
